
import click
from print_pretty import print_pretty


@click.command()
@click.argument('arg')
def cli(arg):

    if arg == 'example1':

        object1 = CustomClass()

        data = {
            "one": "value-one",
            "two": "value-two",
            "three": "value-three",
            "four": {
                '1': '1', '2': '2', '3': [1, 2, 3, 4, 5], '4': {
                    'one': custom_method,
                    'tuple': (1, 2),
                    'unicode': u'\xa7',
                    'two': 'two-value',
                    'three': 'three-value',
                    '3': [1, 2, 3, 4]
                }
             },
            "five": object1

        }

    else:
        raise NotImplementedError

    print_pretty(data)


class CustomClass:
    pass


def custom_method():
    pass



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['print_pretty']

package_data = \
{'': ['*']}

install_requires = \
['click>=7.1.2,<8.0.0',
 'input-util>=0.1.2,<0.2.0',
 'print-dict>=0.1.3,<0.2.0',
 'pyyaml>=5.3.1,<6.0.0',
 'yapf>=0.30.0,<0.31.0']

entry_points = \
{'console_scripts': ['print-pretty = print_pretty.cli:cli']}

setup_kwargs = {
    'name': 'print-pretty',
    'version': '0.1.1',
    'description': '',
    'long_description': '\n# print-pretty\n\n',
    'author': 'Eyal Levin',
    'author_email': 'eyalev@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/eyalev/print-pretty',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
